#include <iostream>
#include <vector>
#include <algorithm>
#include <utility>
#include <climits>

#define endl '\n'

using namespace std;

const int CODES_SIZE = 4;
pair<int, int> compatible_codes[CODES_SIZE][CODES_SIZE];

void print_bits(vector<int>& bits) {
    for (int bit : bits) {
        cout << bit;
    }
    cout << endl;
}

vector<int> find_bits(uint64_t num) {
    vector<int> res;
    while(num > 0) {
        res.push_back(num % 2ll);
        num /= 2ll;
    }

    return res;
}

void initialize_compatible_codes() {
    /// (0, 0) - 0; (0, 1) - 1; (1, 0) - 2; (1, 1) - 3; (-1, -1) - invalid
    compatible_codes[0][0] = compatible_codes[2][0] = {0, 0};
    compatible_codes[0][1] = compatible_codes[2][1] = {1, 1};
    compatible_codes[0][2] = compatible_codes[2][2] = {1, 1};
    compatible_codes[0][3] = compatible_codes[2][3] = {0, 0};

    compatible_codes[1][0] = {-1, -1};
    compatible_codes[1][1] = {0, 1};
    compatible_codes[1][2] = {0, 1};
    compatible_codes[1][3] = {-1, -1};

    compatible_codes[3][0] = {0, 1};
    compatible_codes[3][1] = {-1, -1};
    compatible_codes[3][2] = {-1, -1};
    compatible_codes[3][3] = {0, 1};
}

void find_result(vector<int>& bits_a, vector<int>& bits_b, int bits_size) {
    if (bits_a[0] != bits_b[0]) {
        cout << -1 << endl;
        return;
    }

    uint64_t x = 0, y = 0;
    for (int i = 0; i < bits_size; ++i) {
        int curr_code = bits_a[i] * 2 + bits_b[i];
        int next_code = bits_a[i + 1] * 2 + bits_b[i + 1];

        pair<int, int> needed_bits = compatible_codes[curr_code][next_code];

        // cout << "(" << curr_code << ", " << next_code << ") -> (" << needed_bits.first << ", " << needed_bits.second << ")\n";

        if (needed_bits.first == -1) {
            cout << -1 << endl;
            return;
        }

        if (needed_bits.first == 1) {
            x |= (1ULL << i);
        }
        if (needed_bits.second == 1) {
            y |= (1ULL << i);
        }
    }

    cout << x << " " << y << endl;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    uint64_t a, b;
    cin >> a >> b;

    vector<int> bits_a = find_bits(a);
    vector<int> bits_b = find_bits(b);

    int size_a = (int) bits_a.size();
    int size_b = (int) bits_b.size();

    int bits_size = max(size_a, size_b);
    if (size_a == bits_size) {
        bits_b.insert(bits_b.end(), size_a - size_b, 0);
    } else {
        bits_a.insert(bits_a.end(), size_b - size_a, 0);
    }

    bits_a.push_back(0);
    bits_b.push_back(0);

    initialize_compatible_codes();

    find_result(bits_a, bits_b, bits_size);
return 0;
}
