#include <iostream>
#include <vector>
#include <queue>
#include <algorithm>

#define endl '\n'

using namespace std;

const int MAXN = 2e5 + 3;
int parent[MAXN];
vector<int> graph[MAXN];
pair<int, int> targets[MAXN];

pair<int, int> find_level(int vertex, int level) {
    queue<int> bfs;
    bfs.push(vertex);

    for (int i = 0; i < level; ++i) {
        int queue_size = (int) bfs.size();

        for (int j = 0; j < queue_size; ++j) {
            int currv = bfs.front();
            bfs.pop();

            for (int nextv : graph[currv]) {
                if (nextv != parent[currv]) {
                    bfs.push(nextv);
                }
            }
        }
    }

    int min_vertex = MAXN, max_vertex = -1;
    while (!bfs.empty()) {
        int currv = bfs.front();
        bfs.pop();

        min_vertex = min(min_vertex, currv);
        max_vertex = max(max_vertex, currv);
    }

    return {min_vertex, max_vertex};
}

bool cmp(pair<int, int>& range1, pair<int, int>& range2) {
    if (range1.second == range2.second) {
        return range1.first < range2.first;
    }

    return range1.second < range2.second;
}

pair<int, int> find_perfect_range(int m) {
    sort(targets, targets + m, cmp);

    int ind = 0;
    while (ind + 1 < m and targets[ind].second == targets[ind + 1].second) {
        ++ind;
    }

    if (ind == m - 1) {
        return {targets[ind].first, targets[ind].first};
    }

    int l = targets[ind].second, r = -1;
    ++ind;

    while (ind < m) {
        while (ind + 1 < m and targets[ind].second == targets[ind + 1].second) {
            ++ind;
        }
        r = max(r, targets[ind].first);
        ++ind;
    }

    return (l > r) ? make_pair(r, r) : make_pair(l, r);
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int n;
    cin >> n;

    parent[0] = -1;
    for (int i = 1; i < n; ++i) {
        cin >> parent[i];
        --parent[i];
        graph[parent[i]].push_back(i);
        graph[i].push_back(parent[i]);
    }

    int m;
    cin >> m;

    for (int i = 0; i < m; ++i) {
        int vertex, level;
        cin >> vertex >> level;
        --vertex;

        targets[i] = find_level(vertex, level);
    }

    pair<int, int> res = find_perfect_range(m);
    cout << res.first + 1 << " " << res.second + 1 << endl;
return 0;
}
